@@ -12,6 +12,6 @@ class ConsumerFactory:
     def get_consumer_simple( conn_args, cons_args ):
         kafka_client = KafkaClient( *conn_args.args, **conn_args.kargs )
         t = kafka_client.topics[cons_args.topic]
-        return t.get_simple_consumer( *cons_args.args, *cons_args.kargs )
+        return t.get_simple_consumer( *cons_args.args, **cons_args.kargs )
         
-	
\ No newline at end of file
+	
